# LaTeX Input
Application that allows you to input special symbols anywhere using LaTeX-style inputs.  
Makes inputting special symbols much easier and not limited in scope to a LaTeX editor or PDF.

>∮𝑩⋅𝒅𝒍 = 𝜇₀𝐼  
>∯𝑫⋅𝒅𝑺 = 𝛷ₑ = 𝑄ₑₙᶠʳᵉᵉ  
>𝑃 ⟹ 𝑄 ⟺ ¬𝑃 ∨ 𝑄  
>∃ 𝑥 ∈ ℝ | 𝑥² = 𝑥  
>easy 𝑖𝑡𝑎𝑙𝑖𝑐 or 𝒃𝒐𝒍𝒅 or 𝓈𝒸𝓇𝒾𝓅𝓉 or 𝔉𝔯𝔞𝔨𝔱𝔲𝔯 or 𝕕𝕠𝕦𝕓𝕝𝕖-𝕤𝕥𝕣𝕦𝕔𝕜

Just type <kbd>CapsLock+S</kbd> in any application, enter your desired LaTeX, then press <kbd>Space</kbd> to convert the entered text.  
Data about character variants is parsed directly from UnicodeData.txt, which can be easily updated with the latest version to keep up to date.

___

UnicodeData.txt retrieved from https://www.unicode.org/Public/UCD/latest/ucd/UnicodeData.txt
